@@ -1,4 +1,4 @@
-package Date::Extract::P800Picture 0.104; # -*- cperl; cperl-indent-level: 4 -*-
+package Date::Extract::P800Picture 0.105; # -*- cperl; cperl-indent-level: 4 -*-
 
 use strict;
 use warnings;
@@ -7,7 +7,6 @@ use utf8;
 use 5.014000;
 
 use Moose;
-use namespace::autoclean '-also' => qr/^__/sxm;
 
 use POSIX ();
 use English qw( -no_match_vars);
@@ -153,13 +152,15 @@ __END__
 
 =encoding utf8
 
+=for stopwords Ericsson Filename MERCHANTABILITY POSIX filename timestamp JPG YMDH DateTime undef perl Readonly perls Ipenburg
+
 =head1 NAME
 
 Date::Extract::P800Picture - extract the date from Sony Ericsson P800 pictures.
 
 =head1 VERSION
 
-This document describes Date::Extract::P800Picture version 0.104.
+This document describes Date::Extract::P800Picture version 0.105.
 
 =head1 SYNOPSIS
 
@@ -223,8 +224,6 @@ No configuration and environment settings are used.
 
 =item * L<Moose|Moose>
 
-=item * L<namespace::autoclean|namespace::autoclean>
-
 =item * L<Test::More|Test::More>
 
 =back
@@ -288,7 +287,7 @@ Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 by Roland van Ipenburg
+Copyright 2013 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
